import { Construct } from 'constructs';
import { StringMap, DefaultsProps } from './types';
/**
 * Configuration for the CheckRun event.
 *
 * @stability stable
 */
export interface CheckRunTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'rerequested' | 'completed' | 'requested_action'>;
}
/**
 * Configuration for the CheckSuite event.
 *
 * @stability stable
 */
export interface CheckSuiteTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'rerequested' | 'requested'>;
}
/**
 * Configuration for the IssueComment event.
 *
 * @stability stable
 */
export interface IssueCommentTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'edited' | 'deleted'>;
}
/**
 * Configuration for the Issues event.
 *
 * @stability stable
 */
export interface IssuesTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'opened' | 'edited' | 'deleted' | 'transferred' | 'pinned' | 'unpinned' | 'closed' | 'reopened' | 'assigned' | 'unassigned' | 'labeled' | 'unlabeled' | 'locked' | 'unlocked' | 'milestoned' | 'demilestoned'>;
}
/**
 * Configuration for the Label event.
 *
 * @stability stable
 */
export interface LabelTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'edited' | 'deleted'>;
}
/**
 * Configuration for the Milestone event.
 *
 * @stability stable
 */
export interface MilestoneTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'closed' | 'opened' | 'edited' | 'deleted'>;
}
/**
 * Configuration for the ProjectTypes event.
 *
 * @stability stable
 */
export interface ProjectTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'updated' | 'closed' | 'reopened' | 'edited' | 'deleted'>;
}
/**
 * Configuration for the ProjectCard event.
 *
 * @stability stable
 */
export interface ProjectCardTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'moved' | 'converted' | 'edited' | 'deleted'>;
}
/**
 * Configuration for the ProjectColumn event.
 *
 * @stability stable
 */
export interface ProjectColumnTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'updated' | 'moved' | 'deleted'>;
}
/**
 * Configuration for the PullRequest event.
 *
 * @stability stable
 */
export interface PullRequestTypes extends PushTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types?: Array<'assigned' | 'unassigned' | 'labeled' | 'unlabeled' | 'opened' | 'edited' | 'closed' | 'reopened' | 'synchronize' | 'ready_for_review' | 'locked' | 'unlocked' | 'review_requested' | 'review_request_removed'>;
}
/**
 * Configuration for the PullRequestReview event.
 *
 * @stability stable
 */
export interface PullRequestReviewTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'submitted' | 'edited' | 'dismissed'>;
}
/**
 * Configuration for the PullRequestReviewComment event.
 *
 * @stability stable
 */
export interface PullRequestReviewCommentTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'created' | 'edited' | 'deleted'>;
}
/**
 * Configuration for the PullRequestTarget event.
 *
 * @stability stable
 */
export interface PullRequestTargetTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'assigned' | 'unassigned' | 'labeled' | 'unlabeled' | 'opened' | 'edited' | 'closed' | 'reopened' | 'synchronize' | 'ready_for_review' | 'locked' | 'unlocked' | 'review_requested' | 'review_request_removed'>;
}
/**
 * Configuration for the RegistryPackage event.
 *
 * @stability stable
 */
export interface RegistryPackageTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'published' | 'updated'>;
}
/**
 * Configuration for the Release event.
 *
 * @stability stable
 */
export interface ReleaseTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'published' | 'unpublished' | 'created' | 'edited' | 'deleted' | 'prereleased' | 'released'>;
}
/**
 * Configuration for the Watch event.
 *
 * @stability stable
 */
export interface WatchTypes {
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types: Array<'started'>;
}
/**
 * Configuration for the Push event.
 *
 * @stability stable
 */
export interface PushTypes {
    /**
     * Branches to trigger the workflow on.
     *
     * @stability stable
     */
    readonly branches?: string[];
    /**
     * Branches to ignore when triggering the workflow.
     *
     * @stability stable
     */
    readonly branchesIgnore?: string[];
    /**
     * Tags to trigger the workflow on.
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * Tags to ignore when triggering the workflow.
     *
     * @stability stable
     */
    readonly tagsIgnore?: string[];
    /**
     * Paths to trigger the workflow on.
     *
     * @stability stable
     */
    readonly paths?: string[];
    /**
     * Paths to ignore when triggering the workflow.
     *
     * @stability stable
     */
    readonly pathsIgnore?: string[];
}
/**
 * Configuration for the Schedule event.
 *
 * @stability stable
 */
export interface ScheduleEvent {
    /**
     * A cron schedule to run the workflow on.
     *
     * @stability stable
     */
    readonly schedule: [{
        'cron': string;
    }];
}
/**
 * Configuration for the WorkflowRun event.
 *
 * @stability stable
 */
export interface WorkflowRunEvent {
    /**
     * A list of workflows to trigger from.
     *
     * @stability stable
     */
    readonly workflows: string[];
    /**
     * Branches to trigger this workflow on.
     *
     * @stability stable
     */
    readonly branches?: string[];
    /**
     * Branches to ignore when triggering this workflow.
     *
     * @stability stable
     */
    readonly branchesIgnore?: string[];
    /**
     * Supported types.
     *
     * @stability stable
     */
    readonly types?: Array<'completed' | 'requested'>;
}
/**
 * Events without additional subtypes.
 */
export declare type EventStrings = 'workflowDispatch' | 'repositoryDispatch' | 'create' | 'delete' | 'deployment' | 'deploymentStatus' | 'fork' | 'gollum' | 'pageBuild' | 'public' | 'status';
/**
 * Events with additional subtypes.
 *
 * @stability stable
 */
export interface EventMap {
    /**
     * The checkRun event.
     *
     * @stability stable
     */
    readonly checkRun?: CheckRunTypes;
    /**
     * The checkSuite event.
     *
     * @stability stable
     */
    readonly checkSuite?: CheckSuiteTypes;
    /**
     * The issueComment event.
     *
     * @stability stable
     */
    readonly issueComment?: IssueCommentTypes;
    /**
     * The issues event.
     *
     * @stability stable
     */
    readonly issues?: IssuesTypes;
    /**
     * The label event.
     *
     * @stability stable
     */
    readonly label?: LabelTypes;
    /**
     * The milestone event.
     *
     * @stability stable
     */
    readonly milestone?: MilestoneTypes;
    /**
     * The project event.
     *
     * @stability stable
     */
    readonly project?: ProjectTypes;
    /**
     * The projectCard event.
     *
     * @stability stable
     */
    readonly projectCard?: ProjectCardTypes;
    /**
     * The projectColumn event.
     *
     * @stability stable
     */
    readonly projectColumn?: ProjectColumnTypes;
    /**
     * The pullRequest event.
     *
     * @stability stable
     */
    readonly pullRequest?: PullRequestTypes;
    /**
     * The pullRequestReview event.
     *
     * @stability stable
     */
    readonly pullRequestReview?: PullRequestReviewTypes;
    /**
     * The pullRequestReviewComment event.
     *
     * @stability stable
     */
    readonly pullRequestReviewComment?: PullRequestReviewCommentTypes;
    /**
     * The pullRequestTarget event.
     *
     * @stability stable
     */
    readonly pullRequestTarget?: PullRequestTargetTypes;
    /**
     * The push event.
     *
     * @stability stable
     */
    readonly push?: PushTypes;
    /**
     * The registryPackage event.
     *
     * @stability stable
     */
    readonly registryPackage?: RegistryPackageTypes;
    /**
     * The release event.
     *
     * @stability stable
     */
    readonly release?: ReleaseTypes;
    /**
     * The watch event.
     *
     * @stability stable
     */
    readonly watch?: WatchTypes;
}
/**
 * All the events that can trigger a workflow.
 */
export declare type Events = keyof EventMap | EventStrings;
/**
 * Configuration for a single GitHub Action workflow.
 *
 * @stability stable
 */
export interface WorkflowProps {
    /**
     * Name of the workflow.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * When to run this workflow.
     *
     * @stability stable
     */
    readonly on: Events | Array<Events> | EventMap | ScheduleEvent | WorkflowRunEvent;
    /**
     * A map of environment variables to provide to the job.
     *
     * @stability stable
     */
    readonly env?: StringMap;
    /**
     * A map of default settings to apply to all steps in this job.
     *
     * @stability stable
     */
    readonly defaults?: DefaultsProps;
}
/**
 * Represents a GH Action workflow.
 *
 * @stability stable
 */
export declare class Workflow extends Construct {
    /**
     * File to save synthesized workflow manifest in.
     *
     * @stability stable
     */
    readonly outputFile: string;
    /**
     * An internal representation of a GH Action workflow.
     */
    private readonly action;
    /**
     * Represents a GitHub Actions workflow.
     *
     * @param scope An ActionsStack instance.
     * @param id The name of this workflow.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkflowProps);
    /**
     * Converts the workflow's configuration into a format that is GitHub Actions compatible.
     *
     * @stability stable
     */
    toGHAction(): any;
}
